VideoUrl class

Model containing video URL information

Constructors

VideoUrl({required String url, required String quality, required String mimeType, int? bitrate, int? width, int? height, String? contentLength})

Properties

bitrate int?
final
contentLength String?
final
hashCode int
The hash code for this object.
no setterinherited
height int?
final
mimeType String
final
quality String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final
width int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited