YoutubeUrlExtractor class

Main YouTube URL Extractor

Constructors

YoutubeUrlExtractor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

extractUrls(String videoId) Future<List<VideoUrl>>
Get list of downloadable video URLs
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited